LockedXmlTraits
===============

.. currentmodule:: wwt_data_formats

.. autoclass:: LockedXmlTraits
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~LockedXmlTraits.cross_validation_lock
      ~LockedXmlTraits.rmeta

   .. rubric:: Methods Summary

   .. autosummary::

      ~LockedXmlTraits.add_traits
      ~LockedXmlTraits.apply_to_xml
      ~LockedXmlTraits.class_own_trait_events
      ~LockedXmlTraits.class_own_traits
      ~LockedXmlTraits.class_trait_names
      ~LockedXmlTraits.class_traits
      ~LockedXmlTraits.from_file
      ~LockedXmlTraits.from_text
      ~LockedXmlTraits.from_url
      ~LockedXmlTraits.from_xml
      ~LockedXmlTraits.has_trait
      ~LockedXmlTraits.hold_trait_notifications
      ~LockedXmlTraits.notify_change
      ~LockedXmlTraits.observe
      ~LockedXmlTraits.on_trait_change
      ~LockedXmlTraits.set_trait
      ~LockedXmlTraits.setup_instance
      ~LockedXmlTraits.to_xml
      ~LockedXmlTraits.to_xml_string
      ~LockedXmlTraits.trait_defaults
      ~LockedXmlTraits.trait_events
      ~LockedXmlTraits.trait_has_value
      ~LockedXmlTraits.trait_metadata
      ~LockedXmlTraits.trait_names
      ~LockedXmlTraits.trait_values
      ~LockedXmlTraits.traits
      ~LockedXmlTraits.unobserve
      ~LockedXmlTraits.unobserve_all
      ~LockedXmlTraits.write_xml

   .. rubric:: Attributes Documentation

   .. autoattribute:: cross_validation_lock
   .. autoattribute:: rmeta

   .. rubric:: Methods Documentation

   .. automethod:: add_traits
   .. automethod:: apply_to_xml
   .. automethod:: class_own_trait_events
   .. automethod:: class_own_traits
   .. automethod:: class_trait_names
   .. automethod:: class_traits
   .. automethod:: from_file
   .. automethod:: from_text
   .. automethod:: from_url
   .. automethod:: from_xml
   .. automethod:: has_trait
   .. automethod:: hold_trait_notifications
   .. automethod:: notify_change
   .. automethod:: observe
   .. automethod:: on_trait_change
   .. automethod:: set_trait
   .. automethod:: setup_instance
   .. automethod:: to_xml
   .. automethod:: to_xml_string
   .. automethod:: trait_defaults
   .. automethod:: trait_events
   .. automethod:: trait_has_value
   .. automethod:: trait_metadata
   .. automethod:: trait_names
   .. automethod:: trait_values
   .. automethod:: traits
   .. automethod:: unobserve
   .. automethod:: unobserve_all
   .. automethod:: write_xml
